#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 arch-web
version:              0.3.2
visibility:           public
id:                   arch-web-0.3.2-5GM2D2gpaoaBCYj7aQOpTB
key:                  arch-web-0.3.2-5GM2D2gpaoaBCYj7aQOpTB
license:              MIT
copyright:            Copyright (c) berberman 2020-2025
maintainer:           berberman <berberman@yandex.com>
author:               berberman
stability:            alpha
homepage:             https://github.com/berberman/arch-web
synopsis:             Arch Linux official and AUR web interface binding
description:
    Arch Linux official and AUR web interface binding.
    See README for details.

category:             Web
abi:                  2f34a451a2d55ecd0c505eed8911b2f6
exposed:              True
exposed-modules:
    Web.ArchLinux Web.ArchLinux.API Web.ArchLinux.Types
    Web.ArchLinux.Types.Lens

hidden-modules:
    Web.ArchLinux.Internal.KnownSPDXLoader Web.ArchLinux.Types.API

import-dirs:          /usr/lib/ghc-9.6.6/site-local/arch-web-0.3.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/arch-web-0.3.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/arch-web-0.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-arch-web
hs-libraries:         HSarch-web-0.3.2-5GM2D2gpaoaBCYj7aQOpTB
depends:
    aeson-2.2.1.0-4WRExiZ7zbh8CS1DZxw1Qy base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7
    deriving-aeson-0.2.10-KfqhA0KjeZAH6BIYuOTjjq directory-1.3.8.5
    exceptions-0.10.7 filepath-1.4.300.1
    http-client-0.7.19-1L0tSfBLpxw7thTxok8fUC
    http-client-tls-0.3.6.4-CJvsBVxX93A3NhRpzvN3YA
    http-types-0.12.4-E7NglevSDUe4aFzTHGY2t7
    lens-5.3.4-IAs8Kog1h7NBhXd2ts4yf7 mtl-2.3.1
    servant-0.20.3.0-1acrJQPjM7J97OxGeGwj7N
    servant-client-0.20.3.0-GO4zbZyEkRO5kb9Fc7Xn8v
    servant-client-core-0.20.3.0-5kg4q65c2iDLUOC3rDQMFz
    template-haskell-2.20.0.0 text-2.0.2 time-1.12.2

haddock-interfaces:   /usr/share/doc/haskell-arch-web/html/arch-web.haddock
haddock-html:         /usr/share/doc/haskell-arch-web/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

